@@ -12,6 +12,7 @@ This is the complete API reference:
    biometa
    biosample
    techsample
+   project
    experiment
    experiment_type
    dobject_biometa
@@ -20,7 +21,7 @@ This is the complete API reference:
 """
 # This is lnschema-module vvhc.
 _schema_module_id = "vvhc"
-__version__ = "0.3.1"
+__version__ = "0.3.3"
 _tables = ["biosample", "techsample"]
 
 from ._core import (  # noqa
@@ -28,6 +29,7 @@ from ._core import (  # noqa
     dobject_biometa,
     experiment,
     experiment_type,
+    project,
     readout,
     version_vvhc,
 )
