@@ -1,7 +1,6 @@
 from datetime import datetime as datetime
 from typing import Optional  # noqa
 
-from lnschema_bionty import featureset, species  # noqa
 from sqlmodel import Field, SQLModel
 
 
@@ -42,7 +41,7 @@ class readout(SQLModel, table=True):  # type: ignore
     """Readout of experiments."""
 
     id: Optional[int] = Field(default=None, primary_key=True)
-    efo_id: Optional[str] = None
+    efo_id: str = Field(default=None, unique=True)
     name: Optional[str] = None
     molecule: Optional[str] = None
     instrument: Optional[str] = None
@@ -53,9 +52,12 @@ class experiment(SQLModel, table=True):  # type: ignore
     """Experiments."""
 
     id: Optional[int] = Field(default=None, primary_key=True)
+    exp_id: str = Field(default=None, unique=True)
     name: Optional[str] = None
-    project: Optional[str] = None
+    date: Optional[str] = None
+    project: str = Field(default=None, foreign_key="project.id")
     experiment_type_id: int = Field(default=None, foreign_key="experiment_type.id")
+    time_created: datetime = Field(default_factory=utcnow, nullable=False)
 
 
 class experiment_type(SQLModel, table=True):  # type: ignore
@@ -63,4 +65,12 @@ class experiment_type(SQLModel, table=True):  # type: ignore
 
     id: Optional[int] = Field(default=None, primary_key=True)
     name: Optional[str] = None
-    efo_id: Optional[str] = None
+    efo_id: str = Field(default=None, unique=True)
+
+
+class project(SQLModel, table=True):  # type: ignore
+    """Project."""
+
+    id: Optional[int] = Field(default=None, primary_key=True)
+    proj_id: str = Field(default=None, unique=True)
+    name: Optional[str] = None
